@@ -1,7 +1,7 @@
 from ..util import get_page_soup
 
 
-def fb_league_table(url: str):
+def fb_league_table(url: str) -> list:
     """Returns a list of league table and basic information in a season
 
     Args:
