@@ -2,7 +2,7 @@ import re
 from ..util import get_page_soup
 
 
-def fb_match_lineups(pageSoup=None, url: str = None):
+def fb_match_lineups(pageSoup=None, url: str = None) -> dict:
     """Extracts matchday squad information (formation, starters, bench) for a given match
 
     Args:
