@@ -1,7 +1,7 @@
 from ..util import get_page_soup
 
 
-def fb_match_summary(pageSoup=None, url: str = None):
+def fb_match_summary(pageSoup=None, url: str = None) -> list:
     """Extracts events (goals, bookings, and substitutions) from match summary for a given match
 
     Args:
