@@ -1,7 +1,7 @@
 from ..util import get_page_soup
 
 
-def fb_match_team_stats(pageSoup=None, url: str = None):
+def fb_match_team_stats(pageSoup=None, url: str = None) -> dict:
     """Extracts summary stats for each team in a given match
 
     Args:
