@@ -4,7 +4,7 @@ from .tm_player_market_value import tm_player_market_value
 from .tm_player_transfers import tm_player_transfers
 
 
-def tm_player_data(url: str, currency="EUR"):
+def tm_player_data(url: str, currency="EUR") -> tuple:
     """Extracts metadata, market value history, and transfer history for a given player based on EUR, GBP, or USD currency.
 
     Args:
