@@ -2,7 +2,7 @@ from .util import tm_player_injury_scraper
 from ..util import get_page_soup_headers
 
 
-def tm_player_injury(pageSoup):
+def tm_player_injury(pageSoup) -> list:
 
     """Extracts player injury history and equipped to handle players with multiple pages of injuries
 
