@@ -1,7 +1,7 @@
 import re
 
 
-def tm_player_market_value(pageSoup):
+def tm_player_market_value(pageSoup) -> list:
     """Extracts date, team, and market value from highchart
 
     Args:
