@@ -1,7 +1,7 @@
 import re
 
 
-def tm_player_metadata(pageSoup):
+def tm_player_metadata(pageSoup) -> dict:
     #
     """Extracts general player information (biographical, club, contract, market value, and miscellaneous)
 
