@@ -1,4 +1,4 @@
-def tm_player_transfers(pageSoup):
+def tm_player_transfers(pageSoup) -> list:
 
     """Extracts player transfer information
 
