@@ -3,7 +3,7 @@ from .util import tm_format_currency
 import pandas as pd
 
 
-def tm_team_player_urls(club: str, season: str, currency="EUR"):
+def tm_team_player_urls(club: str, season: str, currency="EUR") -> list:
 
     """Extracts basic player information for each player in a squad including basic player information,
     market value, and contract expiration
