@@ -10,7 +10,7 @@ def tm_team_transfers(
     main_position="All",
     window="All",
     currency="EUR",
-):
+) -> list:
 
     """Extracts player transfer information
 
@@ -23,7 +23,7 @@ def tm_team_transfers(
         currency (str): desired currency to return for values. Defaults to EUR.
 
     Returns:
-        _type_: _description_
+        list: team transfers
     """
 
     # Validate variables
