@@ -1,4 +1,4 @@
-def tm_player_injury_scraper(pageSoup):
+def tm_player_injury_scraper(pageSoup) -> list:
     """Helper function extracts player injury history
 
     Args:
