@@ -2,7 +2,7 @@ import requests
 from bs4 import BeautifulSoup
 
 
-def get_page_soup(url: str):
+def get_page_soup(url: str) -> BeautifulSoup:
     """Returns html of a given url
 
     Args:
@@ -18,7 +18,7 @@ def get_page_soup(url: str):
     return pageSoup
 
 
-def get_page_soup_headers(url: str):
+def get_page_soup_headers(url: str) -> BeautifulSoup:
     """Returns html of a given url
 
     Args:
